@@ -1,5 +1,7 @@
+use std::fmt::Display;
+
 use crate::{
-    http::{header, StatusCode, Uri},
+    http::{header, StatusCode},
     IntoResponse, Response,
 };
 
@@ -17,7 +19,7 @@ use crate::{
 ///
 /// #[handler]
 /// async fn index() -> Redirect {
-///     Redirect::moved_permanent(Uri::from_static("https://www.google.com"))
+///     Redirect::moved_permanent("https://www.google.com")
 /// }
 ///
 /// let app = Route::new().at("/", get(index));
@@ -26,46 +28,46 @@ use crate::{
 /// assert_eq!(resp.status(), StatusCode::MOVED_PERMANENTLY);
 /// assert_eq!(
 ///     resp.headers().get(header::LOCATION),
-///     Some(&HeaderValue::from_static("https://www.google.com/"))
+///     Some(&HeaderValue::from_static("https://www.google.com"))
 /// );
 /// # });
 /// ```
 #[derive(Debug, Clone, Eq, PartialEq)]
 pub struct Redirect {
     status: StatusCode,
-    uri: Uri,
+    uri: String,
 }
 
 impl Redirect {
     /// A simple `308` permanent redirect to a different location.
-    pub fn permanent(uri: Uri) -> Self {
+    pub fn permanent(uri: impl Display) -> Self {
         Self {
             status: StatusCode::PERMANENT_REDIRECT,
-            uri,
+            uri: uri.to_string(),
         }
     }
 
     /// A simple `301` permanent redirect to a different location.
-    pub fn moved_permanent(uri: Uri) -> Self {
+    pub fn moved_permanent(uri: impl Display) -> Self {
         Self {
             status: StatusCode::MOVED_PERMANENTLY,
-            uri,
+            uri: uri.to_string(),
         }
     }
 
     /// A simple `303` redirect to a different location.
-    pub fn see_other(uri: Uri) -> Self {
+    pub fn see_other(uri: impl Display) -> Self {
         Self {
             status: StatusCode::SEE_OTHER,
-            uri,
+            uri: uri.to_string(),
         }
     }
 
     /// A simple `307` temporary redirect to a different location.
-    pub fn temporary(uri: Uri) -> Self {
+    pub fn temporary(uri: impl Display) -> Self {
         Self {
             status: StatusCode::TEMPORARY_REDIRECT,
-            uri,
+            uri: uri.to_string(),
         }
     }
 }
@@ -73,7 +75,7 @@ impl Redirect {
 impl IntoResponse for Redirect {
     fn into_response(self) -> Response {
         self.status
-            .with_header(header::LOCATION, self.uri.to_string())
+            .with_header(header::LOCATION, self.uri)
             .into_response()
     }
 }
@@ -86,7 +88,7 @@ mod tests {
         ($fn:ident, $status:ident) => {
             #[test]
             fn $fn() {
-                let resp = Redirect::$fn(Uri::from_static("https://example.com/")).into_response();
+                let resp = Redirect::$fn("https://example.com/").into_response();
                 assert_eq!(resp.status(), StatusCode::$status);
                 assert_eq!(
                     resp.headers()
